Index: tmp/org.txm.lexicaltable.core/src/org/txm/lexicaltable/core/functions/LexicalTable.java
===================================================================
--- tmp/org.txm.lexicaltable.core/src/org/txm/lexicaltable/core/functions/LexicalTable.java	(revision 1410)
+++ tmp/org.txm.lexicaltable.core/src/org/txm/lexicaltable/core/functions/LexicalTable.java	(revision 1411)
@@ -390,7 +390,7 @@
 			return false;
 		}
 		if(this.property == null)	{
-			Log.severe("LexicalTable.canCompute(): can not compute with no unit property."); //$NON-NLS-1$
+			Log.finest("LexicalTable.canCompute(): can not compute with no unit property."); //$NON-NLS-1$
 			return false;
 		}
 		return true; 
Index: tmp/org.txm.concordance.core/src/org/txm/concordance/core/functions/Concordance.java
===================================================================
--- tmp/org.txm.concordance.core/src/org/txm/concordance/core/functions/Concordance.java	(revision 1410)
+++ tmp/org.txm.concordance.core/src/org/txm/concordance/core/functions/Concordance.java	(revision 1411)
@@ -376,11 +376,11 @@
 	public boolean canCompute() {
 		boolean go = true;
 		if(this.getCorpus() == null)	{
-			System.err.println("Concordance.canCompute(): Corpus is not set.");
+			Log.finest("Concordance.canCompute(): Corpus is not set.");
 			go = false;
 		}
 		if(pQuery == null || pQuery.isEmpty())	{
-			System.err.println("Concordance.canCompute(): Query is not set or empty.");
+			Log.finest("Concordance.canCompute(): Query is not set or empty.");
 			go = false;
 		}
 		return go;
@@ -835,22 +835,6 @@
 		return queryResult.getMatches();
 	}
 
-	@Override
-	public String getName() {
-		try {
-			if (queryResult != null) {
-				return  this.getCorpus().getName()
-						+ " " //$NON-NLS-1$
-						+ queryResult.getQuery().getQueryString();
-			} else {
-				return this.getCorpus().getName();
-			}
-		}
-		catch (Exception e) {
-			return this.getEmptyName();
-		}
-	}
-
 	/**
 	 * Gets the number of lines.
 	 * 
@@ -915,7 +899,7 @@
 
 	@Override
 	public String getSimpleName() {
-		if (pQuery != null) {
+		if (pQuery != null && !pQuery.isEmpty()) {
 			return pQuery.toString();
 		}
 		else	{
@@ -923,6 +907,24 @@
 		}
 	}
 
+	@Override
+	public String getName() {
+		try {
+			if (queryResult != null) {
+				return  this.getCorpus().getName()
+						+ " " //$NON-NLS-1$
+						+ queryResult.getQuery().getQueryString();
+			} else {
+				return this.getCorpus().getName();
+			}
+		}
+		catch (Exception e) {
+			return this.getEmptyName();
+		}
+	}
+
+
+	
 	/**
 	 * Gets the symbol.
 	 *
Index: tmp/org.txm.specificities.core/src/org/txm/specificities/core/functions/Specificities.java
===================================================================
--- tmp/org.txm.specificities.core/src/org/txm/specificities/core/functions/Specificities.java	(revision 1410)
+++ tmp/org.txm.specificities.core/src/org/txm/specificities/core/functions/Specificities.java	(revision 1411)
@@ -44,11 +44,13 @@
 import org.txm.core.results.TXMResult;
 import org.txm.lexicaltable.core.functions.LexicalTable;
 import org.txm.lexicaltable.core.statsengine.data.ILexicalTable;
+import org.txm.objects.CorpusBuild;
 import org.txm.searchengine.cqp.clientExceptions.CqiClientException;
 import org.txm.searchengine.cqp.corpus.CQPCorpus;
 import org.txm.searchengine.cqp.corpus.CQPLexicon;
 import org.txm.searchengine.cqp.corpus.Partition;
 import org.txm.searchengine.cqp.corpus.Property;
+import org.txm.searchengine.cqp.corpus.Subcorpus;
 import org.txm.searchengine.cqp.corpus.WordProperty;
 import org.txm.specificities.core.messages.SpecificitiesCoreMessages;
 import org.txm.specificities.core.preferences.SpecificitiesPreferences;
@@ -113,10 +115,10 @@
 	private CQPLexicon subLexicon;
 
 	/** The corpus. */
-	private CQPCorpus corpus = null;
+	private CQPCorpus corpus;
 
 	/** The sub corpus. */
-	private CQPCorpus subCorpus = null;
+	private CQPCorpus subCorpus;
 
 
 	/**
@@ -162,7 +164,13 @@
 	@Override
 	public boolean loadParameters() {
 		this.lexicalTable = (LexicalTable) this.parent;
-		//this.lexicalTable.setVMaxFilter(Integer.MAX_VALUE); // FIXME: useless?
+		
+		CQPCorpus corpus = CQPCorpus.getFirstParentCorpus(this);
+		this.corpus = corpus;
+		if(corpus instanceof Subcorpus)	{
+			this.subCorpus = corpus;
+		}
+		
 		return true;
 	}
 
@@ -181,7 +189,8 @@
 		this.frequencies = null;
 
 		// delete the specificities selection chart children since they can not be valid anymore if the unit property has changed
-		if (this.hasParameterChanged(TBXPreferences.UNIT_PROPERTY))	{
+		// FIXME: doesn't work
+		if (this.lexicalTable.hasParameterChanged(TBXPreferences.UNIT_PROPERTY))	{
 			this.deleteChildren(SpecificitiesSelection.class);
 		}
 		
@@ -194,7 +203,8 @@
 
 			if (this.lexicalTable.getPartition() != null) {
 				init(symbol, specIndex); 
-			} else {
+			}
+			else {
 				init(rSpecificities.getSymbol(), specIndex); //$NON-NLS-1$
 			}
 		//}
@@ -404,7 +414,7 @@
 	}
 
 	/**
-	 * Name of the part for which specificities are computed.
+	 * Names of the part for which specificities are computed.
 	 *
 	 * @return the part short names
 	 * @throws StatException the stat exception
@@ -415,6 +425,9 @@
 		if (colnames != null && colnames.size() > 0) {
 			return colnames.toArray(new String[]{});
 		}
+		else if (this.subCorpus != null) {
+			return new String[] { this.subCorpus.getName(), this.corpus.getName() + " \\ " + this.subCorpus.getName() }; //$NON-NLS-1$
+		}
 		else if (lexicalTable != null) {
 			// return (colnames != null && colnames.size() != 0) ?
 			// colnames.toArray(new String[]{}) :
@@ -431,8 +444,6 @@
 			catch (Exception e) {
 				return ((Partition)this.lexicalTable.getParent()).getPartNames().toArray(new String[0]);
 			}
-		} else if (this.subCorpus != null) {
-			return new String[] { this.subCorpus.getName(), this.corpus.getName() + " \\ " + this.subCorpus.getName() }; //$NON-NLS-1$
 		}
 		return new String[0];
 	}
@@ -504,24 +515,30 @@
 	 * @throws CqiClientException 
 	 */
 	public int[] getPartSizes() throws StatException, CqiClientException {
-		if (lexicalTable != null) {
+		if (lexicalTable != null && this.subCorpus == null) {
 			
 			try {
-				Vector partsize = lexicalTable.getColMarginsVector();
+				Vector partSizes = lexicalTable.getColMarginsVector();
 				if (colindex != null) {
-					partsize = partsize.get(colindex);
+					partSizes = partSizes.get(colindex);
 				}
-				return partsize.asIntArray();
+				return partSizes.asIntArray();
 			}
 			catch (Exception e) {
 				return ((Partition)this.lexicalTable.getParent()).getPartSizes();
 			}
 			
 			
-		} else {
-			return new int[] { subLexicon.nbrOfToken(),
-					lexicon.nbrOfToken() - subLexicon.nbrOfToken() };
 		}
+		else {
+			try {
+				return new int[] { subLexicon.nbrOfToken(), lexicon.nbrOfToken() - subLexicon.nbrOfToken() };
+			}
+			// case of Subcorpus specificities (the lexicons has not yet been computed)
+			catch (Exception e) {
+				return new int[] {0, 0};
+			}
+		}
 	}
 
 	/**
Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/editors/TXMEditor.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/editors/TXMEditor.java	(revision 1410)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/editors/TXMEditor.java	(revision 1411)
@@ -668,7 +668,7 @@
 					
 					//if (!update || RCPPreferences.getInstance().getBoolean(RCPPreferences.AUTO_UPDATE_EDITOR)) {
 						if (!TXMEditor.this.getResult().compute(monitor)) {
-							Log.severe("TXMEditor.compute(): " + TXMEditor.this.getClass().getSimpleName() + ": computing failed.");
+							Log.finest("TXMEditor.compute(): " + TXMEditor.this.getClass().getSimpleName() + ": computing failed.");
 						}
 					//}
 					notifyExtensions("notifyEndOfCompute"); //$NON-NLS-1$
@@ -682,7 +682,7 @@
 							try {
 								refresh(update);
 							} catch (Exception e) {
-								Log.severe("TXMEditor.compute(): " + TXMEditor.this.getClass().getSimpleName() + ": Error while refreshing the editor: " + e); //$NON-NLS-1$
+								Log.finest("TXMEditor.compute(): " + TXMEditor.this.getClass().getSimpleName() + ": Error while refreshing the editor: " + e); //$NON-NLS-1$
 								Log.printStackTrace(e);
 							}
 						}
@@ -880,10 +880,13 @@
 				continue;
 			}
 
+			Object object = null;
+			Object value = null;
+			
 			try {
 				f.setAccessible(true);
-				Object object = f.get(this);
-				Object value = this.getResult().getParameter(parameter.key(), true); // propagate to parent one time
+				object = f.get(this);
+				value = this.getResult().getParameter(parameter.key(), true); // propagate to parent one time
 
 				if (value == null) {
 					//System.out.println("Warning: "+this.getPartName()+" result "+this.getResult()+" "+parameter.key()+" is not initialized.");
@@ -960,7 +963,9 @@
 					}
 				}
 				else	{
-					f.set(this, value);
+//					if(object != null)	{
+						f.set(this, value);
+	//				}
 				}
 
 				// FIXME: debug
@@ -976,8 +981,11 @@
 			}
 			catch (Exception e) {
 				// TODO Auto-generated catch block
-				e.printStackTrace();
+				if(object != null)	{
+					e.printStackTrace();
+				}
 			}
+
 		}
 
 		// FIXME: Updating the compute button enabled/disabled state
Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/handlers/results/DeleteObject.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/handlers/results/DeleteObject.java	(revision 1410)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/handlers/results/DeleteObject.java	(revision 1411)
@@ -51,6 +51,7 @@
 import org.eclipse.ui.internal.Workbench;
 import org.txm.Toolbox;
 import org.txm.core.engines.EngineType;
+import org.txm.core.messages.TXMCoreMessages;
 import org.txm.core.results.TXMResult;
 import org.txm.rcp.StatusLine;
 import org.txm.rcp.editors.TXMEditor;
@@ -266,9 +267,10 @@
 			}
 			Log.info(NLS.bind(TXMUIMessages.deletedColonP0, ((TXMResult) o)));
 			deleted.add(o);
-		} else {
-			System.out.println("Cant delete: "+o);
 		}
+		else {
+			Log.severe(TXMCoreMessages.bind("Can not delete: {0}.", o));
+		}
 		
 		return deleted;
 	}
Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/adapters/TXMResultAdapter.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/adapters/TXMResultAdapter.java	(revision 1410)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/adapters/TXMResultAdapter.java	(revision 1411)
@@ -57,10 +57,12 @@
 
 	@Override
     public RGB getForeground(Object element) {
+		// debug/advanced mode
 		if(TBXPreferences.getInstance().getBoolean(TBXPreferences.EXPERT_USER) && element instanceof TXMResult && !((TXMResult)element).hasBeenComputedOnce())	{
-	    	Display display = Display.getCurrent();
-	    	Color color = display.getSystemColor(SWT.COLOR_DARK_GRAY);
-	    	return color.getRGB();
+			// highlight results that has not yet been computed
+			Display display = Display.getCurrent();
+		    Color color = display.getSystemColor(SWT.COLOR_DARK_GRAY);
+		    return color.getRGB();
 		}
 		// FIXME: DEbug
 //		else if(element instanceof TXMResult && ((TXMResult)element).isDirty())	{
@@ -74,6 +76,17 @@
 
 	@Override
     public RGB getBackground(Object element) {
+		
+		// debug/advanced mode
+		if(TBXPreferences.getInstance().getBoolean(TBXPreferences.EXPERT_USER) && element instanceof TXMResult && !((TXMResult)element).isVisible())	{
+			// highlight results that are not visible
+			Display display = Display.getCurrent();
+		    //Color color = display.getSystemColor(SWT.COLOR_GRAY);
+			Color color = new Color(display, 240, 240, 240);
+		    return color.getRGB();
+		}
+
+		
 		// FIXME: SJ: tests
 //		if(element instanceof TXMResult && ((TXMResult)element).isUserPersistable())	{
 //	    	Display display = Display.getCurrent();
Index: tmp/org.txm.core/src/java/org/txm/core/results/TXMResult.java
===================================================================
--- tmp/org.txm.core/src/java/org/txm/core/results/TXMResult.java	(revision 1410)
+++ tmp/org.txm.core/src/java/org/txm/core/results/TXMResult.java	(revision 1411)
@@ -1,10 +1,7 @@
 package org.txm.core.results;
 
 import java.io.File;
-import java.io.FileNotFoundException;
 import java.io.IOException;
-import java.io.PrintWriter;
-import java.io.UnsupportedEncodingException;
 import java.lang.reflect.Field;
 import java.text.DateFormat;
 import java.text.SimpleDateFormat;
@@ -13,8 +10,6 @@
 import java.util.Date;
 import java.util.HashMap;
 import java.util.List;
-import java.util.TreeSet;
-import java.util.UUID;
 import java.util.concurrent.Semaphore;
 import java.util.regex.Pattern;
 
@@ -31,7 +26,6 @@
 import org.txm.objects.Project;
 import org.txm.objects.Workspace;
 import org.txm.stat.utils.LogMonitor;
-import org.txm.utils.io.IOUtils;
 import org.txm.utils.logger.Log;
 
 // FIXME: At this moment, an empty list is created for children, to not return
@@ -1221,7 +1215,19 @@
 			this.clean();
 
 			if (this.parent != null) {
+				
+				TXMResult parent = this.parent; 
+				
 				this.parent.removeChild(this);
+				
+				// FIXME: to delete the hidden parent when using shortcut command (eg. Specificities on Partition that hides the parent LexicalTable)
+				// need to prove this method
+				if(!parent.isVisible() &&
+						!(parent instanceof Project) // FIXME: actually removing this test and modify DeleteObject.java method public static List<Object> delete(Object o) by removing the MainCorpus test should work
+						)	{
+					parent.delete();
+				}
+
 			}
 			this.parent = null;
 			return true;
@@ -1976,7 +1982,7 @@
 				Log.finest("TXMResult.compute(): " + this.getClass().getSimpleName() + ": starting parent (" + this.parent.getClass().getSimpleName() + ") computing process...");
 
 				if (!this.parent.compute(monitor, true)) {
-					Log.severe("TXMResult.compute(): " + this.getClass().getSimpleName() + ": failed to compute parent result.");
+					Log.finest("TXMResult.compute(): " + this.getClass().getSimpleName() + ": failed to compute parent result.");
 
 					return false;
 				}
@@ -2017,6 +2023,10 @@
 
 			if(!skipComputing)	{
 
+				// store last used parameters
+//				this.updateLastParameters();
+
+				
 				if (!this.autoSaveParametersFromAnnotations()) {
 					Log.severe("TXMResult.compute(): " + this.getClass().getSimpleName() + ": failed to save parameters from annotations for " + this.getName() + ".");
 				}
Index: tmp/org.txm.core/src/java/org/txm/core/messages/messages.properties
===================================================================
--- tmp/org.txm.core/src/java/org/txm/core/messages/messages.properties	(revision 1410)
+++ tmp/org.txm.core/src/java/org/txm/core/messages/messages.properties	(revision 1411)
@@ -1,131 +1,236 @@
-#TXM messages generated by the PluginMessagesManager class
-#Wed Nov 14 14:12:58 CET 2018
-binaryDirectoryP0NotFound=Binary directory {0} not found.
-cantFindStructuralUnitForMetadataWithIdColon=Can't find structural unit for metadata with id\: 
-catalogFileNotFoundP0=** Catalog File Not found {0}
-checkingBinaryFormat=checking binary format...
-common_absoluteFrequency=Absolute Frequency
-common_cols=Cols
-common_delete=Delete
-common_description=Description
-common_done=Done.
-common_fMax=Fmax
-common_fMin=Fmin
-common_fMinEquals=Fmin\={0}
-common_frequency=Frequency
-common_lowestFrequency=Lowest frequency
-common_numberOfLines=Number of lines
-common_ok=OK
-common_properties=Properties\:
-common_property=Property\:
-common_queriesColonP0=Queries\: {0}.
-common_query=Query 
-common_reference=Reference
-common_rows=Rows
-common_structuralUnitAndProperty=Structural unit and property
-common_structure=Structure
-common_t=t 
-common_thresholds=Thresholds
-common_units=Units
-common_vMax=Vmax
-computingColon=Computing\: 
-connectedToCQP=Connected to CQP.
-corpusColon=Corpus\: 
-corpusColongetLocaleColonCQPIsNotReadyToAnswerColon=Corpus\:getLocale\: CQP is not ready to answer\: 
-couldNotCreateTXMHOMEDirectoryColonP0=** Could not create TXMHOME directory\: {0}.
-couldntReadCorpusColon=Couldn't read corpus\: 
-cQiClientNotInitialized=** CQi Client not initialized
-dataDirectoryIsMissingColonP0='data' directory is missing\: {0}
-doesNotExists=\ does not exists
-encodingColon=, Encoding\: 
-endOfCQPWaitTest=End of CQP waiting test.
-error_error=** Error\: {0}.
-error_error2=Error
-error_errorWhileSortingResult=Error while sorting result.
-eRRORColonExists=ERROR\: \!exists
-errorColonLinkGrplinkAttargetMalformedColonP0=Error\: linkGrp/link/@target malformed\: {0} 
-errorColonP0=** Error\: 
-errorColonP0CorpusDirectoryIsNotConformantToTXM079CorpusBinaryFormatColonCorpusSkipped=** Error\: ''{0}'' corpus directory is not conformant to TXM 0.7.9 corpus binary format\: corpus skipped."  
-errorColonP0CorpusDirectoryIsNotConformantToTXMCorpusBinaryFormatColonCorpusSkipped=** Error\: ''{0}'' corpus directory is not conformant to TXM corpus binary format\: corpus skipped."
-eRRORColonRead=ERROR\: \!read
-errorColonSkippingTheLoadingOfTheP0Corpus=Error\: skipping the loading of the {0} corpus 
-errorColonTheConnexionToTheServerFailedColonWrongPortFormat=** Error \: the connexion to the server failed\: wrong port format\: {0}.
-errorColonThisExceptionShouldNotBeThrown=** Error\: This exception should not be thrown
-errorColonWhileConnectionToSearchEngineWithTheFollowingParametersColon=** Error while connecting to search engine with the following parameters\: {0} and {1}.
-errorConfigdirDirColon=Error configdir dir\: 
-errorDuringWorkspaceInitializationColonP0=** Error during workspace initialization\: {0}
-errorLoadingWorkspaceFromFileColonP0=** Error loading workspace from the {0} file.
-errorRegDirColon=Error reg dir\: 
-errorWhileConnectingToSearchEngine=** Error while connecting CQP server.
-errorWhileGettingMetadatasFromBaseimportMetadatasColon=Error while getting metadatas from Base.importMetadatas\: 
-errorWhileWaitingForCQP=** Error while waiting for CQP\: {0}.
-evaluatingExtensionColonP0FromP1=Evaluating extension\: {0} from {1}
-exceptionColonP0=Exception\: {0}
-failedToAccessStructuralPropertyValues=** Failed to access structural property values 
-failedToCopyTXMFilesFromTXMINSTALLDIRToTXMHOMEColonP0=Failed to copy TXM files from TXMINSTALL DIR to TXMHOME\: {0}.
-failedToCreatePartColon=** Failed to create part\: 
-failedToExec=Failed to exec '{0}\: {1}.
-failedToExecTaskkillIMCqpserverexeFColon=Failed to exec 'taskkill /IM cqpserver.exe /F'\: {0}.
-failedToExecTskillCqpserverexeColon=Failed to exec 'tskill cqpserver.exe'\: {0}.
-failedToGetLastCQPErrorColon=Failed to get last CQP error\: 
-failedToGetSupValuesOf=Failed to get sup values of 
-failedToLoadBaseParametersFromTheP0File=Failed to load base parameters from the {0} file.
-failedToRestorePartition=** Failed to restore partition 
-failedToRestoreSubcorpus=** Failed to restore subcorpus 
-failedToStartMemCqiClientColon=Failed to start CQP in memory mode.
-file=** File
-fillImportxmlWithColon=Fill import.xml with\: 
-filterManagerErrorColonInitializationP0NotFound=** Filter manager initialization error\: {0} not found. 
-fmax=, fmax 
-fmin=, fmin 
-focusIsEmptyOrNull=Focus is empty or null
-hasNoBase=has no base
-htmlDirectoryIsMissingColonP0='html' directory is missing\: {0}
-in=\ in \t\t\t\t\t\t\t\t
-informationsFromWorkspaceSelfElementNull=informations from workspace (selfElement  null)
-initializationOfGroovyImportScriptRunner=Initialization of GroovyImportScriptRunner
-iOColon=IO\: 
-isMissing=is missing
-isNotAValidCQPIDForACorpusItMustBeInUppercaseCharacters=\ is not a valid CQP ID for a corpus. It must be in uppercase characters.
-isNotAValidCQPIdForASubcorpusItMustBeAnUppercaseCharactersFollowedByLowercaseCharacters=\ is not a valid CQP Id for a subcorpus. It must be an uppercase characters followed by lowercase characters.
-killPsAuxPipeGrepCqpserverPipeAwkP=kill `ps aux | grep cqpserver | awk '/-P 
-languageColon=, Language\: 
-loadingExtensions=Loading extensions...
-loadingWorkspaceFromFileColonP0=Loading workspace from the {0} file
-malformedURLFileP0=** Malformed URL\: {0}
-managerErrorDuringInitializationColonP0NotFound=** Manager Error during initialization\: {0} not found.
-matchesFound=matches found.
-noValuesGiven=No values given
-noWorkspaceFoundCreatingANewOneP0=** No workspace found. Creating a new one\: {0}
-numberOfMatch=Number of match 
-numberOfSubMatch=Number of sub match 
-orTheEngineWasNotStartedWithTheCommandLineColon=CQI server failed to started with the command line\: {0}.
-pARAMSColonP0=PARAMS\: 
-parentDirectoryP0NotFound=Parent directory {0} not found.
-print2=/ {print $2}'`
-processing=processing...
-processingTextColonP0=processing text\: {0}
-queryingPartitionP0=Querying partition {0}
-queryOnP0ColonP1InfP2=Query on {0} \: {1} <- {2}
-queryWasColon=Query was\: 
-readCorpusInfosFromOldImportxmlFileColonP0=Read corpus infos from old import.xml file\: {0}
-readError=** Read error
-registryFileIsMissingColonP0='registry' file is missing\: {0}
-reorganizingFilesOfP0=reorganizing files of 
-sAXColon=SAX\: 
-selectionErrorColonTheCorpus=Selection error\: the corpus 
-supBeginningExecutionOfP0=> beginning execution of {0}
-supEndOfExecution=> end of execution 
-textMetadataColon=Text metadata\: 
-theFocusCannotBeNullOrEmpty=The focus cannot be null or empty.
-theFocusIsEmptyOrNull=** The focus is empty or null.
-theP0PartFocusDoesntBelongToPartitionP1=The {0} part focus doesn''t belong to partition {1}.
-ToolboxStatesWorkspaceColonP0=\ Workspace\: {0}
-txmDirectoryIsMissingColonP0='txm' directory is missing\: {0}
-tXMNeedsFoldersColonP0P1P2AndP3=TXM needs folders\: \: {0}, {1}, {2} and {3}.
-unknownPartitionName=** Unknown partition name.
-v=, v 
-warningColonCantLoadCorpus=Warning\: can't load corpus 
-warningColonDuplicateQueryEntryColonP0=Warning\: duplicate query entry\: {0}.
-warningColonQueryFailedColonP0=Warning\: query failed\: {0}.
-wrongLoginOrPasswordOrPortColon=Wrong login, password, host or port in \: {0} {1} {2} {3}.
+#Generated by ResourceBundle Editor (http://essiembre.github.io/eclipse-rbe/)
+#TXM messages generated by the PluginMessagesManager class
+#Wed Nov 14 14:12:58 CET 2018
+
+ToolboxStatesWorkspaceColonP0 = \ Workspace: {0}
+
+binaryDirectoryP0NotFound = Binary directory {0} not found.
+
+cQiClientNotInitialized = ** CQi Client not initialized
+
+cantFindStructuralUnitForMetadataWithIdColon = Can't find structural unit for metadata with id: 
+
+catalogFileNotFoundP0 = ** Catalog File Not found {0}
+
+checkingBinaryFormat = checking binary format...
+
+common_absoluteFrequency         = Absolute Frequency
+common_cols                      = Cols
+common_delete                    = Delete
+common_description               = Description
+common_done                      = Done.
+common_fMax                      = Fmax
+common_fMin                      = Fmin
+common_fMinEquals                = Fmin={0}
+common_frequency                 = Frequency
+common_lowestFrequency           = Lowest frequency
+common_numberOfLines             = Number of lines
+common_ok                        = OK
+common_properties                = Properties
+common_property                  = Property
+common_queriesColonP0            = Queries: {0}.
+common_query                     = Query 
+common_reference                 = Reference
+common_rows                      = Rows
+common_structuralUnitAndProperty = Structural unit and property
+common_structure                 = Structure
+common_t                         = t 
+common_thresholds                = Thresholds
+common_units                     = Units
+common_vMax                      = Vmax
+
+computingColon = Computing: 
+
+connectedToCQP = Connected to CQP.
+
+corpusColon = Corpus: 
+
+corpusColongetLocaleColonCQPIsNotReadyToAnswerColon = Corpus:getLocale: CQP is not ready to answer: 
+
+couldNotCreateTXMHOMEDirectoryColonP0 = ** Could not create TXMHOME directory: {0}.
+
+couldntReadCorpusColon = Couldn't read corpus: 
+
+dataDirectoryIsMissingColonP0 = 'data' directory is missing: {0}
+
+doesNotExists = \ does not exists
+
+eRRORColonExists = ERROR: !exists
+
+eRRORColonRead = ERROR: !read
+
+encodingColon = , Encoding: 
+
+endOfCQPWaitTest = End of CQP waiting test.
+
+errorColonLinkGrplinkAttargetMalformedColonP0 = Error: linkGrp/link/@target malformed: {0} 
+
+errorColonP0 = ** Error: 
+
+errorColonP0CorpusDirectoryIsNotConformantToTXM079CorpusBinaryFormatColonCorpusSkipped = ** Error: ''{0}'' corpus directory is not conformant to TXM 0.7.9 corpus binary format: corpus skipped."  
+
+errorColonP0CorpusDirectoryIsNotConformantToTXMCorpusBinaryFormatColonCorpusSkipped = ** Error: ''{0}'' corpus directory is not conformant to TXM corpus binary format: corpus skipped."
+
+errorColonSkippingTheLoadingOfTheP0Corpus = Error: skipping the loading of the {0} corpus 
+
+errorColonTheConnexionToTheServerFailedColonWrongPortFormat = ** Error : the connexion to the server failed: wrong port format: {0}.
+
+errorColonThisExceptionShouldNotBeThrown = ** Error: This exception should not be thrown
+
+errorColonWhileConnectionToSearchEngineWithTheFollowingParametersColon = ** Error while connecting to search engine with the following parameters: {0} and {1}.
+
+errorConfigdirDirColon = Error configdir dir: 
+
+errorDuringWorkspaceInitializationColonP0 = ** Error during workspace initialization: {0}
+
+errorLoadingWorkspaceFromFileColonP0 = ** Error loading workspace from the {0} file.
+
+errorRegDirColon = Error reg dir: 
+
+errorWhileConnectingToSearchEngine = ** Error while connecting CQP server.
+
+errorWhileGettingMetadatasFromBaseimportMetadatasColon = Error while getting metadatas from Base.importMetadatas: 
+
+errorWhileWaitingForCQP = ** Error while waiting for CQP: {0}.
+
+error_error                                                                            = ** Error: {0}.
+error_error2                                                                           = Error
+error_errorWhileSortingResult                                                          = Error while sorting result.
+
+evaluatingExtensionColonP0FromP1 = Evaluating extension: {0} from {1}
+
+exceptionColonP0 = Exception: {0}
+
+failedToAccessStructuralPropertyValues = ** Failed to access structural property values 
+
+failedToCopyTXMFilesFromTXMINSTALLDIRToTXMHOMEColonP0 = Failed to copy TXM files from TXMINSTALL DIR to TXMHOME: {0}.
+
+failedToCreatePartColon = ** Failed to create part: 
+
+failedToExec = Failed to exec '{0}: {1}.
+
+failedToExecTaskkillIMCqpserverexeFColon = Failed to exec 'taskkill /IM cqpserver.exe /F': {0}.
+
+failedToExecTskillCqpserverexeColon = Failed to exec 'tskill cqpserver.exe': {0}.
+
+failedToGetLastCQPErrorColon = Failed to get last CQP error: 
+
+failedToGetSupValuesOf = Failed to get sup values of 
+
+failedToLoadBaseParametersFromTheP0File = Failed to load base parameters from the {0} file.
+
+failedToRestorePartition = ** Failed to restore partition 
+
+failedToRestoreSubcorpus = ** Failed to restore subcorpus 
+
+failedToStartMemCqiClientColon = Failed to start CQP in memory mode.
+
+file = ** File
+
+fillImportxmlWithColon = Fill import.xml with: 
+
+filterManagerErrorColonInitializationP0NotFound = ** Filter manager initialization error: {0} not found. 
+
+fmax = , fmax 
+
+fmin = , fmin 
+
+focusIsEmptyOrNull = Focus is empty or null
+
+hasNoBase = has no base
+
+htmlDirectoryIsMissingColonP0 = 'html' directory is missing: {0}
+
+iOColon = IO: 
+
+in = \ in \	\	\	\	\	\	\	\	
+
+informationsFromWorkspaceSelfElementNull = informations from workspace (selfElement  null)
+
+initializationOfGroovyImportScriptRunner = Initialization of GroovyImportScriptRunner
+
+isMissing = is missing
+
+isNotAValidCQPIDForACorpusItMustBeInUppercaseCharacters = \ is not a valid CQP ID for a corpus. It must be in uppercase characters.
+
+isNotAValidCQPIdForASubcorpusItMustBeAnUppercaseCharactersFollowedByLowercaseCharacters = \ is not a valid CQP Id for a subcorpus. It must be an uppercase characters followed by lowercase characters.
+
+killPsAuxPipeGrepCqpserverPipeAwkP = kill `ps aux | grep cqpserver | awk '/-P 
+
+languageColon = , Language: 
+
+loadingExtensions = Loading extensions...
+
+loadingWorkspaceFromFileColonP0 = Loading workspace from the {0} file
+
+malformedURLFileP0 = ** Malformed URL: {0}
+
+managerErrorDuringInitializationColonP0NotFound = ** Manager Error during initialization: {0} not found.
+
+matchesFound = matches found.
+
+noValuesGiven = No values given
+
+noWorkspaceFoundCreatingANewOneP0 = ** No workspace found. Creating a new one: {0}
+
+numberOfMatch = Number of match 
+
+numberOfSubMatch = Number of sub match 
+
+orTheEngineWasNotStartedWithTheCommandLineColon = CQI server failed to started with the command line: {0}.
+
+pARAMSColonP0 = PARAMS: 
+
+parentDirectoryP0NotFound = Parent directory {0} not found.
+
+print2 = / {print $2}'`
+
+processing = processing...
+
+processingTextColonP0 = processing text: {0}
+
+queryOnP0ColonP1InfP2 = Query on {0} : {1} <- {2}
+
+queryWasColon = Query was: 
+
+queryingPartitionP0 = Querying partition {0}
+
+readCorpusInfosFromOldImportxmlFileColonP0 = Read corpus infos from old import.xml file: {0}
+
+readError = ** Read error
+
+registryFileIsMissingColonP0 = 'registry' file is missing: {0}
+
+reorganizingFilesOfP0 = reorganizing files of 
+
+sAXColon = SAX: 
+
+selectionErrorColonTheCorpus = Selection error: the corpus 
+
+supBeginningExecutionOfP0 = > beginning execution of {0}
+
+supEndOfExecution = > end of execution 
+
+tXMNeedsFoldersColonP0P1P2AndP3 = TXM needs folders: : {0}, {1}, {2} and {3}.
+
+textMetadataColon = Text metadata: 
+
+theFocusCannotBeNullOrEmpty = The focus cannot be null or empty.
+
+theFocusIsEmptyOrNull = ** The focus is empty or null.
+
+theP0PartFocusDoesntBelongToPartitionP1 = The {0} part focus doesn''t belong to partition {1}.
+
+txmDirectoryIsMissingColonP0 = 'txm' directory is missing: {0}
+
+unknownPartitionName = ** Unknown partition name.
+
+v = , v 
+
+warningColonCantLoadCorpus = Warning: can't load corpus 
+
+warningColonDuplicateQueryEntryColonP0 = Warning: duplicate query entry: {0}.
+
+warningColonQueryFailedColonP0 = Warning: query failed: {0}.
+
+wrongLoginOrPasswordOrPortColon = Wrong login, password, host or port in : {0} {1} {2} {3}.
Index: tmp/org.txm.core/src/java/org/txm/core/messages/messages_ru.properties
===================================================================
--- tmp/org.txm.core/src/java/org/txm/core/messages/messages_ru.properties	(revision 1410)
+++ tmp/org.txm.core/src/java/org/txm/core/messages/messages_ru.properties	(revision 1411)
@@ -1,22 +1,27 @@
-#TXM messages generated by the PluginMessagesManager class
-#Wed Nov 14 14:12:58 CET 2018
-common_cols=
-common_delete=удалить
-common_description=Описание
-common_fMax=
-common_fMin=
-common_frequency=Частотность
-common_lowestFrequency=Минимальная частотность
-common_numberOfLines=Число строк
-common_ok=OK
-common_property=Свойство
-common_queriesColonP0=Запросы\: {0}.
-common_query=Запрос\:
-common_structure=Структура
-common_thresholds=Пороги
-common_units=Единицы
-couldNotCreateTXMHOMEDirectoryColonP0=** Не удалось создать папку TXMHOME \: {0}
-error_error=** Ошибка\: {0}
-error_error2=Ошибка
-error_errorWhileSortingResult=
-failedToCopyTXMFilesFromTXMINSTALLDIRToTXMHOMEColonP0=** Не удалось скопировать файлы из папки TXMINSTALL в TXMHOME\: {0}
+#Generated by ResourceBundle Editor (http://essiembre.github.io/eclipse-rbe/)
+#TXM messages generated by the PluginMessagesManager class
+#Wed Nov 14 14:12:58 CET 2018
+
+common_cols            = 
+common_delete          = удалить
+common_description     = Описание
+common_fMax            = 
+common_fMin            = 
+common_frequency       = Частотность
+common_lowestFrequency = Минимальная частотность
+common_numberOfLines   = Число строк
+common_ok              = OK
+common_property        = Свойство
+common_queriesColonP0  = Запросы: {0}.
+common_query           = Запрос
+common_structure       = Структура
+common_thresholds      = Пороги
+common_units           = Единицы
+
+couldNotCreateTXMHOMEDirectoryColonP0 = ** Не удалось создать папку TXMHOME : {0}
+
+error_error                   = ** Ошибка: {0}
+error_error2                  = Ошибка
+error_errorWhileSortingResult = 
+
+failedToCopyTXMFilesFromTXMINSTALLDIRToTXMHOMEColonP0 = ** Не удалось скопировать файлы из папки TXMINSTALL в TXMHOME: {0}
Index: tmp/org.txm.core/src/java/org/txm/core/messages/messages_fr.properties
===================================================================
--- tmp/org.txm.core/src/java/org/txm/core/messages/messages_fr.properties	(revision 1410)
+++ tmp/org.txm.core/src/java/org/txm/core/messages/messages_fr.properties	(revision 1411)
@@ -1,121 +1,218 @@
-#TXM messages generated by the PluginMessagesManager class
-#Wed Nov 14 14:12:58 CET 2018
-cantFindStructuralUnitForMetadataWithIdColon=Erreur \: pas de structures trouvées pour la métadonnée d'identifiant \: 
-catalogFileNotFoundP0=** Fichier de catalogue introuvable {0}
-checkingBinaryFormat=Vérification du format...
-common_absoluteFrequency=Fréquence absolue
-common_cols=Colonnes
-common_delete=Supprimer
-common_description=Description
-common_done=Terminé.
-common_fMax=Fmax
-common_fMin=Fmin
-common_frequency=Fréquence
-common_lowestFrequency=Fréquence minimale
-common_numberOfLines=Nombre de lignes
-common_ok=OK
-common_properties=Propriétés \:
-common_property=Propriété \:
-common_queriesColonP0=Requêtes \: {0}.
-common_query=Requête 
-common_reference=Référence
-common_rows=Lignes
-common_structuralUnitAndProperty=Unité structurelle et propriété
-common_structure=Structure
-common_t=t
-common_thresholds=Seuils
-common_units=Unités
-computingColon=Calcul\: 
-connectedToCQP=Connecté à CQP.
-corpusColon=Corpus \: 
-corpusColongetLocaleColonCQPIsNotReadyToAnswerColon=Corpus\: getLocale\: CQP est pas prêt à répondre \: 
-couldNotCreateTXMHOMEDirectoryColonP0=** Échec de la création du dossier TXMHOME \: {0}.
-couldntReadCorpusColon=Erreur \: le corpus n'a pas les droits de lecture
-cQiClientNotInitialized=** Le client CQi n'est pas initilialisé
-dataDirectoryIsMissingColonP0=le dossier 'data' est manquant {0}
-doesNotExists=\ n'existe pas.
-encodingColon=, Encodage \: 
-endOfCQPWaitTest=Fin du test d'attente de CQP.
-error_error=** Erreur \: {0}.
-error_error2=Erreur
-error_errorWhileSortingResult=Erreur pendant le tri du résultat.
-eRRORColonExists=Erreur \: n'existe pas
-errorColonLinkGrplinkAttargetMalformedColonP0=Erreur\: linkGrp/link/@target mal formé \: {0}
-errorColonP0=** Erreur \:
-errorColonP0CorpusDirectoryIsNotConformantToTXM079CorpusBinaryFormatColonCorpusSkipped=** Erreur \: le dossier d''entrée n''est pas conforme au format de corpus binaire de TXM 0.7.9 \:    
-errorColonP0CorpusDirectoryIsNotConformantToTXMCorpusBinaryFormatColonCorpusSkipped=** Erreur \: le dossier d''entrée n''est pas conforme au format de corpus binaire de TXM \:
-eRRORColonRead=Erreur \: n'a pas les droits de lecture
-errorColonSkippingTheLoadingOfTheP0Corpus=Erreur \: le corpus {0} ne sera pas chargé
-errorColonTheConnexionToTheServerFailedColonWrongPortFormat=** La connexion au moteur de recherche a échoué \: le port fourni en paramètre n'est pas un nombre entier\: {0}.
-errorColonThisExceptionShouldNotBeThrown=** Erreur \: Cette exception ne devrait pas se lever
-errorColonWhileConnectionToSearchEngineWithTheFollowingParametersColon=** Echec de connexion au moteur de recherche avec les paramètres suivants \: {0} et {1}.
-errorConfigdirDirColon=Erreur dans le dossier de configuration \: 
-errorDuringWorkspaceInitializationColonP0=** Echec de l'initialisation de l'espace de travail \: {0}
-errorLoadingWorkspaceFromFileColonP0=** Echec de lecture de l'espace de travail à partir du fichier {0} 
-errorRegDirColon=Erreur dans le dossier registre \:
-errorWhileConnectingToSearchEngine=** Échec de la connexion au moteur de recherche \: 
-errorWhileGettingMetadatasFromBaseimportMetadatasColon=Erreur lors de la récupération des metadonnées du corpus
-errorWhileWaitingForCQP=** Échec du test d'attente de CQP \: {0}.
-failedToAccessStructuralPropertyValues=** Echec de lecture des valeurs de la propriété de structure 
-failedToCopyTXMFilesFromTXMINSTALLDIRToTXMHOMEColonP0=** Échec de la copie des fichiers TXM du dossier TXMINSTALL vers TXMHOME \: {0}.
-failedToCreatePartColon=** Echec de la création de la partie \:
-failedToExec=Echec de l'exécution de '{0} \: {1}.
-failedToExecTaskkillIMCqpserverexeFColon=Echec de la commande 'taskkill /IM cqpserver.exe /F'\: {0}.
-failedToExecTskillCqpserverexeColon=Echec de la commande 'tskill cqpserver.exe'\: {0}.
-failedToGetLastCQPErrorColon=Erreur lors de la récupération de la dernière erreur CQP \: 
-failedToGetSupValuesOf=Echec de la récupération des valeurs de structures de
-failedToLoadBaseParametersFromTheP0File=Erreur lors  de la récupération des 
-failedToRestorePartition=** Echec de la restauration de la partition
-failedToRestoreSubcorpus=** Echec de la restauration du sous-corpus
-failedToStartMemCqiClientColon=Erreur lors du démarage du mode mémoire de CQP.
-file=** Le fichier 
-fillImportxmlWithColon=Remplissage du fichier 'import.xml' avec \: 
-filterManagerErrorColonInitializationP0NotFound=** Erreur d'initialisation du gestionnaire de filtre \: {0} non trouvé 
-focusIsEmptyOrNull=Le focus est vide ou nul
-hasNoBase=n'a pas de 'Base'
-htmlDirectoryIsMissingColonP0=le dossier 'html' est manquant {0}
-in=\ dans
-informationsFromWorkspaceSelfElementNull=informations from workspace (selfElement  null)
-initializationOfGroovyImportScriptRunner=Initialisation de GroovyImportScriptRunner
-iOColon=IO \:
-isMissing=''{0}'' est introuvable.
-isNotAValidCQPIDForACorpusItMustBeInUppercaseCharacters=\ n'est pas un identifiant de corpus CQP valide. Il doit être en majuscule.
-isNotAValidCQPIdForASubcorpusItMustBeAnUppercaseCharactersFollowedByLowercaseCharacters=\ n'est pas un identifiant de sous-corpus CQP valide. Il doit être en majuscules suivies de caractères minuscules.
-killPsAuxPipeGrepCqpserverPipeAwkP=kill `ps aux | grep cqpserver | awk '/-P 
-languageColon=, Langue \: 
-managerErrorDuringInitializationColonP0NotFound=** Erreur d''initialisation du gestionnaire de catalogue \: {0} non trouvé  
-matchesFound=résultats trouvés
-noValuesGiven=Pas de valeur donnée
-noWorkspaceFoundCreatingANewOneP0=** Pas d'espace de travail trouvé, création d'un nouvel espace de travail dans le dossier {0} 
-numberOfMatch=Nombre de match
-numberOfSubMatch=Nombre de sous graph
-orTheEngineWasNotStartedWithTheCommandLineColon=Le démarrage du serveur CQI a échoué avec la ligne de commande \: {0}.
-pARAMSColonP0=Paramètres \: {0}
-print2=/ {print $2}'`
-processing=traitement en cours...
-processingTextColonP0=traitement du fichier \: {0}
-queryingPartitionP0=Requête sur la partition {0}
-queryOnP0ColonP1InfP2=Requête sur {0} \: {1} <- {2}
-queryWasColon=La requête était \: 
-readCorpusInfosFromOldImportxmlFileColonP0=Lecture des informatins sur le corpus depuis le fichier import.xml \: {0} 
-readError=** Erreur de lecture
-registryFileIsMissingColonP0=le dossier 'registry' est manquant {0}
-reorganizingFilesOfP0=Reorganisation des fichiers de {0}
-sAXColon=SAX \: 
-selectionErrorColonTheCorpus=Erreur \: le corpus
-supBeginningExecutionOfP0=> début de l'exécution de {0} 
-supEndOfExecution=> fin de l'exécution
-textMetadataColon=Métadonnées de textes \: 
-theFocusCannotBeNullOrEmpty=Le focus ne doit pas être vide ou nul.
-theFocusIsEmptyOrNull=** Le focus est vide ou nul.
-theP0PartFocusDoesntBelongToPartitionP1=Le focus de la partie {0} n''appartient pas à la partition {1}.
-txmDirectoryIsMissingColonP0=le dossier 'txm' est manquant {0}
-tXMNeedsFoldersColonP0P1P2AndP3=TXM a besoin des dossiers suivants \: {0}, {1}, {2} et {3}.
-unknownPartitionName=** Nom de partition inconnu.
-warningColonCantLoadCorpus=Attention\: le corpus ne peut pas être chargé 
-warningColonDuplicateQueryEntryColonP0=Attention \: requête dupliquée \: {0}.
-warningColonQueryFailedColonP0=Attention \: échec de la requête\: {0}.
-wrongLoginOrPasswordOrPortColon=Mauvais login, mot de passe, nom de machine ou port dans \: {0} {1} {2} {3}.
-xmlValidationColonP0DoesNotExists=Validation XML \: {0} n'existe pas ?
-xmlValidationColonP0IsADirectory=Validation XML \: {0} est un dossier
-xmlValidationColonP0IsNotReadable=Validation XML \: {0} n'a pas les bon droits de lecture
+#Generated by ResourceBundle Editor (http://essiembre.github.io/eclipse-rbe/)
+#TXM messages generated by the PluginMessagesManager class
+#Wed Nov 14 14:12:58 CET 2018
+
+cQiClientNotInitialized = ** Le client CQi n'est pas initilialisé
+
+cantFindStructuralUnitForMetadataWithIdColon = Erreur : pas de structures trouvées pour la métadonnée d'identifiant : 
+
+catalogFileNotFoundP0 = ** Fichier de catalogue introuvable {0}
+
+checkingBinaryFormat = Vérification du format...
+
+common_absoluteFrequency         = Fréquence absolue
+common_cols                      = Colonnes
+common_delete                    = Supprimer
+common_description               = Description
+common_done                      = Terminé.
+common_fMax                      = Fmax
+common_fMin                      = Fmin
+common_frequency                 = Fréquence
+common_lowestFrequency           = Fréquence minimale
+common_numberOfLines             = Nombre de lignes
+common_ok                        = OK
+common_properties                = Propriétés
+common_property                  = Propriété
+common_queriesColonP0            = Requêtes : {0}.
+common_query                     = Requête 
+common_reference                 = Référence
+common_rows                      = Lignes
+common_structuralUnitAndProperty = Unité structurelle et propriété
+common_structure                 = Structure
+common_t                         = t
+common_thresholds                = Seuils
+common_units                     = Unités
+
+computingColon = Calcul: 
+
+connectedToCQP = Connecté à CQP.
+
+corpusColon = Corpus : 
+
+corpusColongetLocaleColonCQPIsNotReadyToAnswerColon = Corpus: getLocale: CQP est pas prêt à répondre : 
+
+couldNotCreateTXMHOMEDirectoryColonP0 = ** Échec de la création du dossier TXMHOME : {0}.
+
+couldntReadCorpusColon = Erreur : le corpus n'a pas les droits de lecture
+
+dataDirectoryIsMissingColonP0 = le dossier 'data' est manquant {0}
+
+doesNotExists = \ n'existe pas.
+
+eRRORColonExists = Erreur : n'existe pas
+
+eRRORColonRead = Erreur : n'a pas les droits de lecture
+
+encodingColon = , Encodage : 
+
+endOfCQPWaitTest = Fin du test d'attente de CQP.
+
+errorColonLinkGrplinkAttargetMalformedColonP0 = Erreur: linkGrp/link/@target mal formé : {0}
+
+errorColonP0 = ** Erreur :
+
+errorColonP0CorpusDirectoryIsNotConformantToTXM079CorpusBinaryFormatColonCorpusSkipped = ** Erreur : le dossier d''entrée n''est pas conforme au format de corpus binaire de TXM 0.7.9 :    
+
+errorColonP0CorpusDirectoryIsNotConformantToTXMCorpusBinaryFormatColonCorpusSkipped = ** Erreur : le dossier d''entrée n''est pas conforme au format de corpus binaire de TXM :
+
+errorColonSkippingTheLoadingOfTheP0Corpus = Erreur : le corpus {0} ne sera pas chargé
+
+errorColonTheConnexionToTheServerFailedColonWrongPortFormat = ** La connexion au moteur de recherche a échoué : le port fourni en paramètre n'est pas un nombre entier: {0}.
+
+errorColonThisExceptionShouldNotBeThrown = ** Erreur : Cette exception ne devrait pas se lever
+
+errorColonWhileConnectionToSearchEngineWithTheFollowingParametersColon = ** Echec de connexion au moteur de recherche avec les paramètres suivants : {0} et {1}.
+
+errorConfigdirDirColon = Erreur dans le dossier de configuration : 
+
+errorDuringWorkspaceInitializationColonP0 = ** Echec de l'initialisation de l'espace de travail : {0}
+
+errorLoadingWorkspaceFromFileColonP0 = ** Echec de lecture de l'espace de travail à partir du fichier {0} 
+
+errorRegDirColon = Erreur dans le dossier registre :
+
+errorWhileConnectingToSearchEngine = ** Échec de la connexion au moteur de recherche : 
+
+errorWhileGettingMetadatasFromBaseimportMetadatasColon = Erreur lors de la récupération des metadonnées du corpus
+
+errorWhileWaitingForCQP = ** Échec du test d'attente de CQP : {0}.
+
+error_error                                                                            = ** Erreur : {0}.
+error_error2                                                                           = Erreur
+error_errorWhileSortingResult                                                          = Erreur pendant le tri du résultat.
+
+failedToAccessStructuralPropertyValues = ** Echec de lecture des valeurs de la propriété de structure 
+
+failedToCopyTXMFilesFromTXMINSTALLDIRToTXMHOMEColonP0 = ** Échec de la copie des fichiers TXM du dossier TXMINSTALL vers TXMHOME : {0}.
+
+failedToCreatePartColon = ** Echec de la création de la partie :
+
+failedToExec = Echec de l'exécution de '{0} : {1}.
+
+failedToExecTaskkillIMCqpserverexeFColon = Echec de la commande 'taskkill /IM cqpserver.exe /F': {0}.
+
+failedToExecTskillCqpserverexeColon = Echec de la commande 'tskill cqpserver.exe': {0}.
+
+failedToGetLastCQPErrorColon = Erreur lors de la récupération de la dernière erreur CQP : 
+
+failedToGetSupValuesOf = Echec de la récupération des valeurs de structures de
+
+failedToLoadBaseParametersFromTheP0File = Erreur lors  de la récupération des 
+
+failedToRestorePartition = ** Echec de la restauration de la partition
+
+failedToRestoreSubcorpus = ** Echec de la restauration du sous-corpus
+
+failedToStartMemCqiClientColon = Erreur lors du démarage du mode mémoire de CQP.
+
+file = ** Le fichier 
+
+fillImportxmlWithColon = Remplissage du fichier 'import.xml' avec : 
+
+filterManagerErrorColonInitializationP0NotFound = ** Erreur d'initialisation du gestionnaire de filtre : {0} non trouvé 
+
+focusIsEmptyOrNull = Le focus est vide ou nul
+
+hasNoBase = n'a pas de 'Base'
+
+htmlDirectoryIsMissingColonP0 = le dossier 'html' est manquant {0}
+
+iOColon = IO :
+
+in = \ dans
+
+informationsFromWorkspaceSelfElementNull = informations from workspace (selfElement  null)
+
+initializationOfGroovyImportScriptRunner = Initialisation de GroovyImportScriptRunner
+
+isMissing = ''{0}'' est introuvable.
+
+isNotAValidCQPIDForACorpusItMustBeInUppercaseCharacters = \ n'est pas un identifiant de corpus CQP valide. Il doit être en majuscule.
+
+isNotAValidCQPIdForASubcorpusItMustBeAnUppercaseCharactersFollowedByLowercaseCharacters = \ n'est pas un identifiant de sous-corpus CQP valide. Il doit être en majuscules suivies de caractères minuscules.
+
+killPsAuxPipeGrepCqpserverPipeAwkP = kill `ps aux | grep cqpserver | awk '/-P 
+
+languageColon = , Langue : 
+
+managerErrorDuringInitializationColonP0NotFound = ** Erreur d''initialisation du gestionnaire de catalogue : {0} non trouvé  
+
+matchesFound = résultats trouvés
+
+noValuesGiven = Pas de valeur donnée
+
+noWorkspaceFoundCreatingANewOneP0 = ** Pas d'espace de travail trouvé, création d'un nouvel espace de travail dans le dossier {0} 
+
+numberOfMatch = Nombre de match
+
+numberOfSubMatch = Nombre de sous graph
+
+orTheEngineWasNotStartedWithTheCommandLineColon = Le démarrage du serveur CQI a échoué avec la ligne de commande : {0}.
+
+pARAMSColonP0 = Paramètres : {0}
+
+print2 = / {print $2}'`
+
+processing = traitement en cours...
+
+processingTextColonP0 = traitement du fichier : {0}
+
+queryOnP0ColonP1InfP2 = Requête sur {0} : {1} <- {2}
+
+queryWasColon = La requête était : 
+
+queryingPartitionP0 = Requête sur la partition {0}
+
+readCorpusInfosFromOldImportxmlFileColonP0 = Lecture des informatins sur le corpus depuis le fichier import.xml : {0} 
+
+readError = ** Erreur de lecture
+
+registryFileIsMissingColonP0 = le dossier 'registry' est manquant {0}
+
+reorganizingFilesOfP0 = Reorganisation des fichiers de {0}
+
+sAXColon = SAX : 
+
+selectionErrorColonTheCorpus = Erreur : le corpus
+
+supBeginningExecutionOfP0 = > début de l'exécution de {0} 
+
+supEndOfExecution = > fin de l'exécution
+
+tXMNeedsFoldersColonP0P1P2AndP3 = TXM a besoin des dossiers suivants : {0}, {1}, {2} et {3}.
+
+textMetadataColon = Métadonnées de textes : 
+
+theFocusCannotBeNullOrEmpty = Le focus ne doit pas être vide ou nul.
+
+theFocusIsEmptyOrNull = ** Le focus est vide ou nul.
+
+theP0PartFocusDoesntBelongToPartitionP1 = Le focus de la partie {0} n''appartient pas à la partition {1}.
+
+txmDirectoryIsMissingColonP0 = le dossier 'txm' est manquant {0}
+
+unknownPartitionName = ** Nom de partition inconnu.
+
+warningColonCantLoadCorpus = Attention: le corpus ne peut pas être chargé 
+
+warningColonDuplicateQueryEntryColonP0 = Attention : requête dupliquée : {0}.
+
+warningColonQueryFailedColonP0 = Attention : échec de la requête: {0}.
+
+wrongLoginOrPasswordOrPortColon = Mauvais login, mot de passe, nom de machine ou port dans : {0} {1} {2} {3}.
+
+xmlValidationColonP0DoesNotExists = Validation XML : {0} n'existe pas ?
+
+xmlValidationColonP0IsADirectory = Validation XML : {0} est un dossier
+
+xmlValidationColonP0IsNotReadable = Validation XML : {0} n'a pas les bon droits de lecture
Index: tmp/org.txm.ahc.rcp/src/org/txm/ahc/rcp/handlers/ComputeAHC.java
===================================================================
--- tmp/org.txm.ahc.rcp/src/org/txm/ahc/rcp/handlers/ComputeAHC.java	(revision 1410)
+++ tmp/org.txm.ahc.rcp/src/org/txm/ahc/rcp/handlers/ComputeAHC.java	(revision 1411)
@@ -79,63 +79,82 @@
 		if (selection instanceof AHC) {
 			ahc = (AHC) selection;
 		}
-		// creates from CA
-		else if (selection instanceof CA) { // the CA is visible only when the selection is a CA
-			ahc = new AHC((CA) selection);
-		}
-		else if (selection instanceof PartitionIndex) {
-			PartitionIndex index = (PartitionIndex)selection;
-			CA ca = new CA(new LexicalTable(index));
-			ca.setVisible(false);
-			ahc = new AHC(ca);
-		}
-		// creates from LexicalTable
-		else if (selection instanceof LexicalTable) {
-			LexicalTable lexicaltable = (LexicalTable) selection;
-			CA ca = new CA(lexicaltable);
-			ca.setVisible(false);
-			ahc = new AHC(ca);
-		}
-		// creates from Partition
-		else if (selection instanceof Partition) {
-			//System.out.println("Compute CAH with Partition : "+((Partition)selection.getFirstElement()).getName());
-			Partition partition = (Partition)selection;
-			if (partition.getPartsCount() < 4) {
-				MessageDialog d = new MessageDialog(window.getShell(), TXMCoreMessages.error_error2, null,
-						NLS.bind(AHCUIMessages.error_canNotComputeAHCWith, partition.getPartsCount()), 0, new String[] { TXMCoreMessages.common_ok}, 0);
-				d.open();
-				return null;
+		// Creating
+		else {
+
+			LexicalTable lexicalTable = null;
+			CA ca = null;
+			
+			// Creating from CA
+			if (selection instanceof CA) {
+				ca = (CA) selection;
+				lexicalTable = ca.getLexicalTable();
+				ahc = new AHC(ca);
 			}
-			try {
-				String title = AHCUIMessages.bind(AHCUIMessages.computingClassificationWithP0, partition.getName());
-				int vMax = CAPreferences.getInstance().getInt(TXMPreferences.V_MAX);
-				int fMin =  CAPreferences.getInstance().getInt(TXMPreferences.F_MIN);
-				Shell shell = Display.getCurrent().getActiveShell();
-				CAParametersDialog d = new CAParametersDialog(shell, partition.getParent(), title);
-				d.setFminAndVMax(fMin, vMax);
-				
-				if (d.open() == Window.OK) {
-					WordProperty property = d.getProperty();
-					fMin = d.getFmin();
-					vMax = d.getMaxLines();
+			// Creating from Partition Index
+			else if (selection instanceof PartitionIndex) {
+				PartitionIndex index = (PartitionIndex)selection;
+				lexicalTable = new LexicalTable(index);
+				ca = new CA(lexicalTable);
+				ahc = new AHC(ca);
+			}
+			// Creating from Lexical Table
+			else if (selection instanceof LexicalTable) {
+				lexicalTable = (LexicalTable) selection;
+				ca = new CA(lexicalTable);
+				ahc = new AHC(ca);
+			}
+			// Creating from Partition
+			else if (selection instanceof Partition) {
+				Partition partition = (Partition)selection;
+				if (partition.getPartsCount() < 4) {
+					MessageDialog d = new MessageDialog(window.getShell(), TXMCoreMessages.error_error2, null,
+							NLS.bind(AHCUIMessages.error_canNotComputeAHCWith, partition.getPartsCount()), 0, new String[] { TXMCoreMessages.common_ok}, 0);
+					d.open();
+					return null;
+				}
+				try {
+					String title = AHCUIMessages.bind(AHCUIMessages.computingClassificationWithP0, partition.getName());
+					int vMax = CAPreferences.getInstance().getInt(TXMPreferences.V_MAX);
+					int fMin =  CAPreferences.getInstance().getInt(TXMPreferences.F_MIN);
+					Shell shell = Display.getCurrent().getActiveShell();
+					CAParametersDialog d = new CAParametersDialog(shell, partition.getParent(), title);
+					d.setFminAndVMax(fMin, vMax);
 					
-					LexicalTable lexicalTable = new LexicalTable(partition); // use the CAPreferencePage Fmin
-					lexicalTable.setParameters(property, fMin, vMax, null);
-					CA ca = new CA(lexicalTable);
-					ca.setVisible(false);
-					ahc = new AHC(ca);
-				}
-				// canceled
-				else {
+					if (d.open() == Window.OK) {
+						WordProperty property = d.getProperty();
+						fMin = d.getFmin();
+						vMax = d.getMaxLines();
+						
+						lexicalTable = new LexicalTable(partition); // use the CAPreferencePage Fmin
+						lexicalTable.setParameters(property, fMin, vMax, null);
+						ca = new CA(lexicalTable);
+						ahc = new AHC(ca);
+					}
+					// canceled
+					else {
+						return null;
+					}
+				} catch (Exception e) {
+					Log.severe("Failed to build the lexical table of " + partition + ": " + e);
+					Log.printStackTrace(e);
 					return null;
-				}
-			} catch (Exception e) {
-				Log.severe("Failed to build the lexical table of " + partition + ": " + e);
-				Log.printStackTrace(e);
-				return null;
-			} 
+				} 
+			}
+			
+			// show the lexical table only if the command was called from a lexical table
+			if(!(selection instanceof LexicalTable))	{
+				lexicalTable.setVisible(false);
+			}
+			
+			// show the CA only if the command was called from a CA
+			if(!(selection instanceof CA))	{
+				ca.setVisible(false);
+			}
+			
 		}
-
+		
+		
 		ChartEditor.openEditor(ahc);
 		return null;
 	}
Index: tmp/org.txm.specificities.rcp/src/org/txm/specificities/rcp/editors/SpecificitiesSelectionEditor.java
===================================================================
--- tmp/org.txm.specificities.rcp/src/org/txm/specificities/rcp/editors/SpecificitiesSelectionEditor.java	(revision 1410)
+++ tmp/org.txm.specificities.rcp/src/org/txm/specificities/rcp/editors/SpecificitiesSelectionEditor.java	(revision 1411)
@@ -1,6 +1,8 @@
 package org.txm.specificities.rcp.editors;
 
 import org.eclipse.swt.SWT;
+import org.eclipse.swt.layout.GridLayout;
+import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.ToolItem;
 import org.txm.chartsengine.rcp.editors.ChartEditor;
@@ -53,10 +55,16 @@
 		
 		
 		// Banality
-        Label label = new Label(this.getExtendedParametersGroup(), SWT.NONE);
-        label.setText("Banality:");
+		Composite extendedParametersArea = this.getExtendedParametersGroup();
+		GridLayout gridLayout = new GridLayout();
+		gridLayout.numColumns = 2;
+		extendedParametersArea.setLayout(gridLayout);
 		
-		banality = new FloatSpinner(this.getExtendedParametersGroup(), SWT.BORDER);
+		
+        Label label = new Label(extendedParametersArea, SWT.NONE);
+        label.setText("Banality");
+		
+		banality = new FloatSpinner(extendedParametersArea, SWT.BORDER);
 		banality.setToolTipText("Banality threshold");
 		banality.setMaximumAsFloat(200);
 		banality.addSelectionListener(computeSelectionListener);
Index: tmp/org.txm.specificities.rcp/src/org/txm/specificities/rcp/handlers/ComputeSpecifities.java
===================================================================
--- tmp/org.txm.specificities.rcp/src/org/txm/specificities/rcp/handlers/ComputeSpecifities.java	(revision 1410)
+++ tmp/org.txm.specificities.rcp/src/org/txm/specificities/rcp/handlers/ComputeSpecifities.java	(revision 1411)
@@ -96,19 +96,13 @@
 				}
 				specificities = new Specificities(lexicalTable);
 				
+				// show the lexical table only if the command was called from a lexical table
 				if(!(selection instanceof LexicalTable))	{
 					lexicalTable.setVisible(false);
 				}
-
-				//lexicalTable.setVisible(false);
 			}
-			
-//			if(!(selection instanceof LexicalTable))	{
-//				lexicalTable.setVisible(false);
-//			}
 
 			TXMEditor.openEditor(specificities, SpecificitiesEditor.ID);
-//			TXMEditor.openEditor(lexicalTable, LexicalTableEditor.ID);
 			
 		}
 		catch (Exception e) {
Index: tmp/org.txm.ca.rcp/src/org/txm/ca/rcp/editors/CAParametersDialog.java
===================================================================
--- tmp/org.txm.ca.rcp/src/org/txm/ca/rcp/editors/CAParametersDialog.java	(revision 1410)
+++ tmp/org.txm.ca.rcp/src/org/txm/ca/rcp/editors/CAParametersDialog.java	(revision 1411)
@@ -160,7 +160,7 @@
 			anaPropLabel.setText(mess);
 		}
 		else {
-			anaPropLabel.setText(TXMCoreMessages.common_properties);
+			anaPropLabel.setText(TXMCoreMessages.common_property);
 		}
 		anaPropLabel.setLayoutData(new GridData(GridData.END, GridData.CENTER,
 				false, false));
@@ -180,7 +180,7 @@
 		anaPropCombo.select(iword);
 
 		maxlinesLabel = new Label(composite, SWT.NONE);
-		maxlinesLabel.setText(TXMUIMessages.numberOfLinesColon);
+		maxlinesLabel.setText(TXMCoreMessages.common_numberOfLines);
 		maxlinesLabel.setLayoutData(new GridData(GridData.END, GridData.CENTER, true, false));
 		maxlinesSpinner = new Spinner(composite, SWT.BORDER);
 		maxlinesSpinner.setLayoutData(new GridData(GridData.FILL, GridData.CENTER, true, false));
Index: tmp/org.txm.ca.rcp/src/org/txm/ca/rcp/handlers/ComputeCA.java
===================================================================
--- tmp/org.txm.ca.rcp/src/org/txm/ca/rcp/handlers/ComputeCA.java	(revision 1410)
+++ tmp/org.txm.ca.rcp/src/org/txm/ca/rcp/handlers/ComputeCA.java	(revision 1411)
@@ -79,102 +79,109 @@
 
 		try {
 			System.out.println(CAUIMessages.creatingCA);
+
+			LexicalTable lexicalTable = null;
 			CA ca = null;
 
-			// Creating from Partition
-			if (selection instanceof Partition) {
+			// Reopening an existing result
+			if (selection instanceof CA) {
+				ca = (CA) selection;
+			}
+			// Creating
+			else {
+				// Creating from Partition
+				if (selection instanceof Partition) {
 
-				final Partition partition = (Partition) selection;
+					final Partition partition = (Partition) selection;
 
-				// not enough parts error
-				if (partition.getPartsCount() < 4) {
-					Display.getDefault().syncExec(new Runnable() {
-						
-						@Override
-						public void run() {
-							MessageDialog d = new MessageDialog(window.getShell(), TXMCoreMessages.error_error2, null,
-									NLS.bind(CAUIMessages.canNotComputeFactorialAnalysisWithOnlyP0PartsTheMinimumIs4Parts, partition.getPartsCount()), 0, new String[] { TXMCoreMessages.common_ok}, 0);
-							d.open();
-						}
-					});
-					return null;
-				}
-				
-				// FIXME: old version using dialog box for parameters
-				// ask property and Fmins and Vmax
-//				String title = TXMUIMessages.bind(CAUIMessages.ComputeCorrespondanceAnalysisDialog_0, partition.getName());
-//				CAParametersDialog d = new CAParametersDialog(window.getShell(), partition.getParent(), title);
-//
-//				if (d.open() == MessageDialog.OK) {
-//					WordProperty property = d.getProperty();
-//					int fMin = d.getFmin();
-//					int vMax = d.getMaxLines();
-//
-//					Log.info(NLS.bind(CAUIMessages.computingCorrespondenceAnalysisOnP0WithPropertyP1, partition, property));
-//
-//					LexicalTable lexicalTable = new LexicalTable(partition);
-//					lexicalTable.setParameters(property, fMin, vMax, null);
-//					ca = new CA(lexicalTable);
-//				} else { // aborted
-//					return null;
-//				}
+					// not enough parts error
+					if (partition.getPartsCount() < 4) {
+						Display.getDefault().syncExec(new Runnable() {
 
-				// FIXME: SJ: temporary version before we fix the problems listed below
-				LexicalTable lexicalTable = new LexicalTable(partition);
-				lexicalTable.setParameters((WordProperty) partition.getCorpus().getDefaultProperty(), 20, 200, null);
-				ca = new CA(lexicalTable);
+							@Override
+							public void run() {
+								MessageDialog d = new MessageDialog(window.getShell(), TXMCoreMessages.error_error2, null, NLS.bind(CAUIMessages.canNotComputeFactorialAnalysisWithOnlyP0PartsTheMinimumIs4Parts, partition.getPartsCount()), 0, new String[] { TXMCoreMessages.common_ok }, 0);
+								d.open();
+							}
+						});
+						return null;
+					}
 
-				
-				// FIXME: SJ: new version, creating a, empty LT and an empty CA
-				// does not work at this time because of some problems in CAEditor (refreshing and components creation + eigenvalues computing)
-//				ca = new CA(new LexicalTable(partition));
-			}
-			else if (selection instanceof PartitionIndex) {
-				PartitionIndex index = (PartitionIndex) selection;
-				Property property = index.getProperties().get(0);
-				
-				if (index.getPartition().getPartsCount() < 4) {
-					// FIXME: remove this swing code that freeze the UI, need to use SWT in main thread
-					MessageBox.error(CAUIMessages.canNotComputeCAOnLexicalTableWithLessThan4Columns);
-					return null;
+					// FIXME: old version using dialog box for parameters
+					// ask property and Fmins and Vmax
+					//				String title = TXMUIMessages.bind(CAUIMessages.ComputeCorrespondanceAnalysisDialog_0, partition.getName());
+					//				CAParametersDialog d = new CAParametersDialog(window.getShell(), partition.getParent(), title);
+					//
+					//				if (d.open() == MessageDialog.OK) {
+					//					WordProperty property = d.getProperty();
+					//					int fMin = d.getFmin();
+					//					int vMax = d.getMaxLines();
+					//
+					//					Log.info(NLS.bind(CAUIMessages.computingCorrespondenceAnalysisOnP0WithPropertyP1, partition, property));
+					//
+					//					LexicalTable lexicalTable = new LexicalTable(partition);
+					//					lexicalTable.setParameters(property, fMin, vMax, null);
+					//					ca = new CA(lexicalTable);
+					//				} else { // aborted
+					//					return null;
+					//				}
+
+					// FIXME: SJ: temporary version before we fix the problems listed below
+					lexicalTable = new LexicalTable(partition);
+					lexicalTable.setParameters((WordProperty) partition.getCorpus().getDefaultProperty(), 20, 200, null);
+					ca = new CA(lexicalTable);
+
+					// FIXME: SJ: new version, creating a, empty LT and an empty CA
+					// does not work at this time because of some problems in CAEditor (refreshing and components creation + eigenvalues computing)
+					//				ca = new CA(new LexicalTable(partition));
 				}
-				if (index.hasBeenComputedOnce() && index.getAllLines().size() < 4) {
-					// FIXME: remove this swing code that freeze the UI, need to use SWT in main thread
-					MessageBox.error(CAUIMessages.canNotComputeCAWithLessThan4RowsInTheTable);
-					return null;
+				else if (selection instanceof PartitionIndex) {
+					PartitionIndex index = (PartitionIndex) selection;
+					Property property = index.getProperties().get(0);
+					lexicalTable = new LexicalTable(index);
+					
+					if (index.getPartition().getPartsCount() < 4) {
+						// FIXME: remove this swing code that freeze the UI, need to use SWT in main thread
+						MessageBox.error(CAUIMessages.canNotComputeCAOnLexicalTableWithLessThan4Columns);
+						return null;
+					}
+					if (index.hasBeenComputedOnce() && index.getAllLines().size() < 4) {
+						// FIXME: remove this swing code that freeze the UI, need to use SWT in main thread
+						MessageBox.error(CAUIMessages.canNotComputeCAWithLessThan4RowsInTheTable);
+						return null;
+					}
+
+					Log.info(NLS.bind(CAUIMessages.computingCorrespondenceAnalysisOnP0WithPropertyP1, index, property));
+					ca = new CA(lexicalTable);
 				}
+				// Creating from Lexical Table
+				else if (selection instanceof LexicalTable) {
+					lexicalTable = (LexicalTable) selection;
+					Property property = lexicalTable.getProperty();
 
-				Log.info(NLS.bind(CAUIMessages.computingCorrespondenceAnalysisOnP0WithPropertyP1, index, property));
-				ca = new CA(new LexicalTable(index));
-			}
-			// Creating from Lexical Table
-			else if (selection instanceof LexicalTable) {
-				LexicalTable lexicalTable = (LexicalTable) selection;
-				Property property = lexicalTable.getProperty();
+					Log.info(NLS.bind(CAUIMessages.computingCorrespondenceAnalysisOnP0WithPropertyP1, lexicalTable, property));
 
-				Log.info(NLS.bind(CAUIMessages.computingCorrespondenceAnalysisOnP0WithPropertyP1, lexicalTable, property));
+					if (lexicalTable.getNColumns() < 4) {
+						// FIXME: remove this swing code that freeze the UI, need to use SWT in main thread
+						MessageBox.error(CAUIMessages.canNotComputeCAOnLexicalTableWithLessThan4Columns);
+						return null;
+					}
+					if (lexicalTable.getNRows() < 4) {
+						// FIXME: remove this swing code that freeze the UI, need to use SWT in main thread
+						MessageBox.error(CAUIMessages.canNotComputeCAWithLessThan4RowsInTheTable);
+						return null;
+					}
 
-				if (lexicalTable.getNColumns() < 4) {
-					// FIXME: remove this swing code that freeze the UI, need to use SWT in main thread
-					MessageBox.error(CAUIMessages.canNotComputeCAOnLexicalTableWithLessThan4Columns);
-					return null;
+					ca = new CA(lexicalTable);
 				}
-				if (lexicalTable.getNRows() < 4) {
-					// FIXME: remove this swing code that freeze the UI, need to use SWT in main thread
-					MessageBox.error(CAUIMessages.canNotComputeCAWithLessThan4RowsInTheTable);
-					return null;
+				
+				// show the lexical table only if the command was called from a lexical table
+				if(!(selection instanceof LexicalTable))	{
+					lexicalTable.setVisible(false);
 				}
 
-				ca = new CA(lexicalTable);
 			}
-			// Reopening an existing result
-			else if (selection instanceof CA) {
-				ca = (CA) selection;
-			}
-			else {
-				Log.severe(CAUIMessages.bind(CAUIMessages.error_cannot_compute_with_selection, selection));
-				return null;
-			}
+
 			// FIXME: should be done in the CAEditor
 			// compute the CA
 			ca.compute();

Index: tmp/org.txm.specificities.rcp/src/org/txm/specificities/rcp/editors/SpecificitiesEditor.java
===================================================================
--- tmp/org.txm.specificities.rcp/src/org/txm/specificities/rcp/editors/SpecificitiesEditor.java	(revision 1410)
+++ tmp/org.txm.specificities.rcp/src/org/txm/specificities/rcp/editors/SpecificitiesEditor.java	(revision 1411)
@@ -33,6 +33,7 @@
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.layout.GridData;
+import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.ScrollBar;
@@ -56,7 +57,7 @@
 import org.txm.utils.logger.Log;
 
 /**
- * Displays a table editor with specificities index.
+ * Displays a table editor with specificities indexes.
  * 
  * @author mdecorde
  * @author sjacquot
@@ -90,7 +91,7 @@
 	 * Maximum score.
 	 */
 	@Parameter(key=SpecificitiesPreferences.MAX_SCORE)
-	protected Spinner maxScore;
+	protected Spinner maxScoreFilter;
 
 	
 	
@@ -111,18 +112,24 @@
 						this.getResult().getUnitProperty(), false);
 			}
 			
+
 			// Extended parameters
 			Composite extendedParametersArea = this.getExtendedParametersGroup();
+			GridLayout gridLayout = new GridLayout();
+			gridLayout.numColumns = 2;
+			extendedParametersArea.setLayout(gridLayout);
 			
 			// max score
-			new Label(extendedParametersArea, SWT.NONE).setText("Maximum score");
-			this.maxScore = new Spinner(extendedParametersArea, SWT.BORDER);
-			this.maxScore.setToolTipText("The maximum score to display");
-			this.maxScore.setMinimum(0);
-
+			Label maxScoreLabel = new Label(extendedParametersArea, SWT.NONE);
+			maxScoreLabel.setText("Maximum score");
 			
+			this.maxScoreFilter = new Spinner(extendedParametersArea, SWT.BORDER);
+			this.maxScoreFilter.setToolTipText("The maximum score to display");
+			this.maxScoreFilter.setMinimum(0);
 			
-			// result area
+			
+			
+			// Result area
 			GLComposite resultArea = this.getResultArea();
 			resultArea.getLayout().numColumns = 2;
 
@@ -192,48 +199,57 @@
 	@Override
 	public void updateEditorFromResult(boolean update) {
 		try {
-
 			
-			if(!update && this.getResult().hasBeenComputedOnce())	{
-				String[] partNames = null;
-				int[] partSize = null;
+			if(!update
+//					//&& this.getResult().hasBeenComputedOnce()
+					)	{
+				String[] lexicalTableColumnNames = null;
+				int[] lexicalTableColumnTotalFrequencies = null;
 				try {
-					partNames = this.getResult().getPartShortNames();
-					partSize = this.getResult().getPartSizes();
+					lexicalTableColumnNames = this.getResult().getPartShortNames();
+					lexicalTableColumnTotalFrequencies = this.getResult().getPartSizes();
 				} catch (Exception e) {
 					Log.severe(NLS.bind(RCoreMessages.error_unexpectedErrorInRStatisticsEngine, e));
 					Log.printStackTrace(e);
 					return;
 				}
 
 				// remove part columns if exist
 //				for (int firstPartColumnIndex = 3; firstPartColumnIndex < specificitesTable.getColumnCount(); firstPartColumnIndex++) {
 //					specificitesTable.getColumn(firstPartColumnIndex).dispose();
 //				}
 				
 				// System.out.println("partnames: "+Arrays.toString(partNames));
-				 // for each part
-				for (int i = 0, firstPartColumnIndex = 2; i < partNames.length ; i++) {
+				 // for each lexical table column
+				for (int i = 0, firstLexicalTableColumnIndex = 3; i < lexicalTableColumnNames.length ; i++, firstLexicalTableColumnIndex += 2) {
 
+					System.err.println("SpecificitiesEditor.updateEditorFromResult() creating column freq at index " + firstLexicalTableColumnIndex);
+					
 					//FREQ COLUMN
 					final TableColumn freqpartTableColumn = new TableColumn(specificitesTable, SWT.NONE);
-					freqpartTableColumn.setText(partNames[i] + " t=" + partSize[i]); //$NON-NLS-1$ 
-					freqpartTableColumn.setToolTipText(partNames[i] + " t=" + partSize[i]); //$NON-NLS-1$ 
-					// System.out.println("create column "+partNames[i]);
+					freqpartTableColumn.setText(lexicalTableColumnNames[i] + " t=" + lexicalTableColumnTotalFrequencies[i]); //$NON-NLS-1$ 
+					freqpartTableColumn.setToolTipText(lexicalTableColumnNames[i] + " t=" + lexicalTableColumnTotalFrequencies[i]); //$NON-NLS-1$ 
+					//System.out.println("create column "+lexicalTableColumnNames[i]);
 					freqpartTableColumn.setAlignment(SWT.RIGHT);
 					freqpartTableColumn.pack();
 					
-					viewerComparator.addSelectionAdapter(viewer, freqpartTableColumn, ++firstPartColumnIndex);
+					viewerComparator.addSelectionAdapter(viewer, freqpartTableColumn, firstLexicalTableColumnIndex);
 
+					
+					System.err.println("SpecificitiesEditor.updateEditorFromResult() creating column score at index " + (firstLexicalTableColumnIndex + 1));
+					
 					//SCORE COLUMN
-					final TableColumn partTableColumn = new TableColumn(specificitesTable, SWT.NONE);
-					partTableColumn.setText("score");//partNames[i] + " t=" + partSize[i]); //$NON-NLS-1$ 
-					partTableColumn.setToolTipText(partNames[i] + " t=" + partSize[i]); //$NON-NLS-1$ 
+					final TableColumn lexicalTableColumn = new TableColumn(specificitesTable, SWT.NONE);
+					lexicalTableColumn.setText("score"); 
+					lexicalTableColumn.setToolTipText(lexicalTableColumnNames[i] + " t=" + lexicalTableColumnTotalFrequencies[i]); //$NON-NLS-1$ 
 					// System.out.println("create column "+partNames[i]);
-					partTableColumn.setAlignment(SWT.RIGHT);
-					partTableColumn.pack();
+					lexicalTableColumn.setAlignment(SWT.RIGHT);
+					lexicalTableColumn.pack();
 
-					viewerComparator.addSelectionAdapter(viewer, partTableColumn, ++firstPartColumnIndex);
+					viewerComparator.addSelectionAdapter(viewer, lexicalTableColumn, (firstLexicalTableColumnIndex + 1));
 				}
 			}
 			
@@ -255,16 +271,18 @@
 				//final int[] sortedPartIndexes = specificitesResult.getSortedPartIndexes();
 	
 				// Create an array of lines to fill the tables
-						System.out.println("len types: "+typeNames.length);
-						System.out.println("len freq: "+typeFreq.length);
-						System.out.println("len specfreqs: "+specFreqs.length);
-						System.out.println("len specidx: "+specIndex.length);
-				 Object[] tableLines = new Object[typeNames.length];
+				Log.finest("len types: "+typeNames.length);
+				Log.finest("len freq: "+typeFreq.length);
+				Log.finest("len specfreqs: "+specFreqs.length);
+				Log.finest("len specidx: "+specIndex.length);
+				
+				Object[] tableLines = new Object[typeNames.length];
 				for (int j = 0; j < tableLines.length; j++) {
 					tableLines[j] = new Object[] { typeNames[j], new Integer(typeFreq[j]), specFreqs[j], specIndex[j] };
 				}
 				viewer.setInput(tableLines);
-			} else {
+			}
+			else {
 				viewer.setInput(null);
 			}
 
@@ -192,48 +199,57 @@
 				}
 
-				// remove part columns if exist
-//				for (int firstPartColumnIndex = 3; firstPartColumnIndex < specificitesTable.getColumnCount(); firstPartColumnIndex++) {
-//					specificitesTable.getColumn(firstPartColumnIndex).dispose();
+				// remove lexical table columns if already exist
+//				int columnsCount = specificitesTable.getColumnCount();
+//				System.out.println("SpecificitiesEditor.updateEditorFromResult(): column count = " + columnsCount);
+//				for (int firstLexicalTableColumnIndex = 3; firstLexicalTableColumnIndex < columnsCount - 1; firstLexicalTableColumnIndex++) {
+//					System.err.println("SpecificitiesEditor.updateEditorFromResult() removing column " + firstLexicalTableColumnIndex);
+//					specificitesTable.getColumn(firstLexicalTableColumnIndex).dispose();
 //				}
 				